==> org-lsst-ccs-subsystem-fcs-gui-4.0.7-sources.jar: org/lsst/ccs/subsystems/fcs/autochanger/ui/AutochangerGatherPanel.java <==

package org.lsst.ccs.subsystems.fcs.autochanger.ui;

import java.util.List;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import org.lsst.ccs.bus.data.KeyValueData;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutoChanger;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutoChangerTrucks;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerLatch;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerOnlineClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerThreeClamps;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerTruck;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerTwoLatches;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByEPOSController;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByHardware;
import org.lsst.ccs.subsystems.fcs.ui.commons.EPOSControllerPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.GatherPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.PlutoGatewayPanel;

/**
 * This panel gathers all the panels needed for the autochanger GUI.
 * Except the subsystemPanel which is handled by the GeneralPanel.
 * It takes care of the initialization of the panels and the update of the panels.
 *
 * @author virieux
 */
public class AutochangerGatherPanel extends GatherPanel {
    private static final long serialVersionUID = -975949078768889254L;
    
    private static final String AC_PLUTO_GATEWAY_NAME= "acSensorsGateway";
    private static final String AC_TRUCKS_NAME= "autochangerTrucks";

    protected InterfaceAutochangerGUI subs;

    //CANopen devices panels
    protected EPOSControllerPanel linearRailMasterControllerPanel;
    protected EPOSControllerPanel linearRailSlaveControllerPanel;
    protected EPOSControllerPanel latchXminusControllerPanel;
    protected EPOSControllerPanel latchXplusControllerPanel;
    protected EPOSControllerPanel onlineClampXminusControllerPanel;
    protected EPOSControllerPanel onlineClampXplusControllerPanel;
    protected EPOSControllerPanel onlineClampYminusControllerPanel;
    protected PlutoGatewayPanel plutoGatewayPanel;
    
    private EPOSControllerPanel[] controllerPanelsList; 

    //Exchanger hardware panels
    protected AutochangerThreeOnlineClampsPanel onlineClampsPanel;
    
    
    private AutochangerTwoTrucksPanel acTrucksPanel;
    private AutochangerTwoLatchesPanel acLatchesPanel = new AutochangerTwoLatchesPanel();
    private AutochangerThreeOnlineClampsPanel acClampsPanel = new AutochangerThreeOnlineClampsPanel();
    private final AutochangerGeneralViewPanel acGeneralViewPanel = new AutochangerGeneralViewPanel();

    public AutochangerGatherPanel(String tcpProxyName) {
        super(tcpProxyName);
        initPanels();
        setName("AutochangerGatherPanel");
    }

    public AutochangerGatherPanel(InterfaceAutochangerGUI subs, String tcpProxyName) {
        super(tcpProxyName);
        initPanels();
        this.subs = subs;
        this.acClampsPanel.setSubsystem(subs);
        this.acLatchesPanel.setSubsystem(subs);
        this.acTrucksPanel.setSubsystem(subs);
        this.linearRailMasterControllerPanel.setSubsystem(subs);
        this.linearRailSlaveControllerPanel.setSubsystem(subs);
        this.latchXminusControllerPanel.setSubsystem(subs);
        this.latchXplusControllerPanel.setSubsystem(subs);
        this.onlineClampXminusControllerPanel.setSubsystem(subs);
        this.onlineClampXplusControllerPanel.setSubsystem(subs);
        this.onlineClampYminusControllerPanel.setSubsystem(subs);
        setName("AutochangerGatherPanel");
    }



    public AutochangerTwoTrucksPanel getAcTrucksPanel() {
        return acTrucksPanel;
    }

    public AutochangerTwoLatchesPanel getAcLatchesPanel() {
        return acLatchesPanel;
    }

    public AutochangerThreeOnlineClampsPanel getAcClampsPanel() {
        return acClampsPanel;
    }

    public AutochangerGeneralViewPanel getAcGeneralViewPanel() {
        return acGeneralViewPanel;
    }

    public EPOSControllerPanel getLinearRailMasterControllerPanel() {
        return linearRailMasterControllerPanel;
    }

    public EPOSControllerPanel getLinearRailSlaveControllerPanel() {
        return linearRailSlaveControllerPanel;
    }

    public EPOSControllerPanel getLatchXminusControllerPanel() {
        return latchXminusControllerPanel;
    }

    public EPOSControllerPanel getLatchXplusControllerPanel() {
        return latchXplusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampXminusControllerPanel() {
        return onlineClampXminusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampXplusControllerPanel() {
        return onlineClampXplusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampYminusControllerPanel() {
        return onlineClampYminusControllerPanel;
    }

    public PlutoGatewayPanel getPlutoGatewayPanel() {
        return plutoGatewayPanel;
    }

    @Override
    public void initializeGUIWithConfigInfo(ConfigurationInfo configInfo,
            List<String> hardwareNames) {
        super.initializeGUIWithConfigInfo(configInfo, hardwareNames);
        SwingUtilities.invokeLater(new GuiInitialization(configInfo));
    }
    
    /**
     * Update GUI when a StatusConfigurationInfo message is received on the status bus. 
     * @param configInfo
     */
    @Override
    public void updateFromConfigurationInfo(ConfigurationInfo configInfo) {
        SwingUtilities.invokeLater(new GuiInitialization(configInfo));
    }
    
    @Override
    public void updateFromStatusData(KeyValueData data) {

        if (CHANGER_TCPPROXY_NAME.equals(data.getKey())) {
            updateCanOpenHardwarePanel((StatusDataPublishedByHardware)data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutoChanger) {
            updateAutochanger((StatusDataPublishedByAutoChanger) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByEPOSController) {
            updateController(data.getKey(),(StatusDataPublishedByEPOSController) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerTruck) {
            updateTruck(data.getKey(),(StatusDataPublishedByAutochangerTruck) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutoChangerTrucks) {
            updateTrucks((StatusDataPublishedByAutoChangerTrucks) data.getValue());

        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerLatch) {
            updateLatch((StatusDataPublishedByAutochangerLatch) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerTwoLatches) {
            updateLatches((StatusDataPublishedByAutochangerTwoLatches) data.getValue());

        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerOnlineClamp) {
            updateOnlineClamp(data.getKey(), (StatusDataPublishedByAutochangerOnlineClamp) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerThreeClamps) {
            updateClamps((StatusDataPublishedByAutochangerThreeClamps) data.getValue());
        }
    }
    
    /**
     * updates hardware information (fields booted, initialized) from StatusDataPublishedByHardware object.
     * @param status 
     */
    @Override
    public void updateCanOpenHardwarePanel(StatusDataPublishedByHardware status) {
        super.updateCanOpenHardwarePanel(status);
        this.plutoGatewayPanel.updateDevice(status);
        for (EPOSControllerPanel ctlPanel: controllerPanelsList) {
            ctlPanel.updateDevice(status);
        }
    }
    
    private void updateController(String controllerName, StatusDataPublishedByEPOSController controllerStatus) {
        
        switch (controllerName) {
            case "linearRailMasterController":
                updateLinearRailMasterController(controllerStatus);
                break;

            case "linearRailSlaveController":
                updateLinearRailSlaveController(controllerStatus);
                break;

            case "latchXminusController":
                updateLatchXminusController(controllerStatus);
                break;

            case "latchXplusController":
                updateLatchXplusController(controllerStatus);
                break;

            case "onlineClampXminusController":
                updateOnlineClampXminusController(controllerStatus);
                break;

            case "onlineClampXplusController":
                updateOnlineClampXplusController(controllerStatus);
                break;

            case "onlineClampYminusController":
                updateOnlineClampYminusController(controllerStatus);
                break;
                
            default:
                FCSLOG.warning(getName() + " An unexpected onlineClamp name was read on the status bus:" 
                        + controllerName);
                break;    
        }
    }
    
    private void updateOnlineClamp(String clampName, StatusDataPublishedByAutochangerOnlineClamp status) {
        switch (clampName) {
            case "onlineClampXminus":
                updateClampXminus(status);
                break;

            case "onlineClampXplus":
                updateClampXplus(status);
                break;

            case "onlineClampYminus":
                updateClampYminus(status);
                break;
                
            default:
                FCSLOG.warning(getName() + " An unexpected onlineClamp name was read on the status bus:" 
                        + clampName);
                break;
        }
    }



    

    /**
     * Initialization of the GUI for data stored in tcpConfiguration. *
     */
    private class GuiInitialization implements Runnable {

        private final ConfigurationInfo configInfo;

        public GuiInitialization(ConfigurationInfo configInfo) {
            this.configInfo = configInfo;
        }

        @Override
        public void run() {



            //** Autochanger General View Panel **/
            acGeneralViewPanel.initializeGui(configInfo);

            /**
             * Autochanger Clamps Panel *
             */
            acClampsPanel.initializeGui(configInfo);

            /**
             * Autochanger Latches Panel *
             */
            acLatchesPanel.initializeGui(configInfo);

            /**
             * Autochanger Trucks Panel *
             */
            
            acTrucksPanel.initializeGui(configInfo);

            /**
             * Linear Rail Master Controller Panel *
             */
            linearRailMasterControllerPanel.initializeGui(configInfo);

            /**
             * Linear Rail Slave Controller Panel*
             */
            linearRailSlaveControllerPanel.initializeGui(configInfo);

            /**
             * Latch Xminus Controller Panel*
             */
            latchXminusControllerPanel.initializeGui(configInfo);

            /**
             * Latch Xplus Controller Panel*
             */
            latchXplusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Xminus Controller Panel*
             */
            onlineClampXminusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Xplus Controller Panel*
             */
            onlineClampXplusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Z Controller Panel*
             */
            onlineClampYminusControllerPanel.initializeGui(configInfo);

            /**
             * PlutoGateway Panel*
             */
            plutoGatewayPanel.initializeGui(configInfo);

        }
    }


    public void updateLinearRailMasterController(StatusDataPublishedByEPOSController s) {
        linearRailMasterControllerPanel.updateController(s);
    }

    public void updateLinearRailSlaveController(StatusDataPublishedByEPOSController s) {
        linearRailSlaveControllerPanel.updateController(s);
    }

    public void updateLatchXminusController(StatusDataPublishedByEPOSController s) {
        latchXminusControllerPanel.updateController(s);
    }

    public void updateLatchXplusController(StatusDataPublishedByEPOSController s) {
        latchXplusControllerPanel.updateController(s);
    }

    public void updateOnlineClampXminusController(StatusDataPublishedByEPOSController s) {
        onlineClampXminusControllerPanel.updateController(s);
    }

    public void updateOnlineClampXplusController(StatusDataPublishedByEPOSController s) {
        onlineClampXplusControllerPanel.updateController(s);
    }

    public void updateOnlineClampYminusController(StatusDataPublishedByEPOSController s) {
        onlineClampYminusControllerPanel.updateController(s);
    }

    protected void updateClampXminus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampXminus(s);
    }

    protected void updateClampXplus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampXplus(s);
    }

    protected void updateClampYminus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampYminus(s);
    }

    protected void updateClamps(StatusDataPublishedByAutochangerThreeClamps s) {
        this.acClampsPanel.updateClamps(s);
        this.acGeneralViewPanel.updateClamps(s);
    }

    protected void updateAutochanger(StatusDataPublishedByAutoChanger s) {
        this.acGeneralViewPanel.updateAutochanger(s);
    }

    protected void updateLatch(StatusDataPublishedByAutochangerLatch s) {
        this.acLatchesPanel.updateLatch(s);
    }

    protected void updateLatches(StatusDataPublishedByAutochangerTwoLatches s) {
        this.acLatchesPanel.updateLatches(s);
        this.acGeneralViewPanel.updateLatches(s);
    }
    
    protected void updateTruck(String truckName,StatusDataPublishedByAutochangerTruck s) {
        this.acTrucksPanel.updateTruck(truckName,s);
    }
    
    protected void updateTrucks(StatusDataPublishedByAutoChangerTrucks s) {
        this.acTrucksPanel.updateTrucks(s);
        this.acGeneralViewPanel.updateTrucks(s);
    }

    private void initPanels() {
        //controllers Panels
        linearRailMasterControllerPanel = new EPOSControllerPanel("linearRailMasterController");
        linearRailSlaveControllerPanel = new EPOSControllerPanel("linearRailSlaveController");
        latchXminusControllerPanel = new EPOSControllerPanel("latchXminusController");
        latchXplusControllerPanel = new EPOSControllerPanel("latchXplusController");
        onlineClampXminusControllerPanel = new EPOSControllerPanel("onlineClampXminusController");
        onlineClampXplusControllerPanel = new EPOSControllerPanel("onlineClampXplusController");
        onlineClampYminusControllerPanel = new EPOSControllerPanel("onlineClampYminusController");
        controllerPanelsList = new EPOSControllerPanel[] {linearRailMasterControllerPanel, linearRailSlaveControllerPanel, 
            latchXminusControllerPanel,latchXplusControllerPanel, 
            onlineClampXminusControllerPanel, onlineClampXplusControllerPanel, onlineClampYminusControllerPanel};
        //plutoGatewayPanel
        plutoGatewayPanel = new PlutoGatewayPanel(AC_PLUTO_GATEWAY_NAME);

        acClampsPanel = new AutochangerThreeOnlineClampsPanel();
        acLatchesPanel = new AutochangerTwoLatchesPanel();
        acTrucksPanel = new AutochangerTwoTrucksPanel(AC_TRUCKS_NAME);
    }
    
    @Override
    public void resetPanel() {
        super.resetPanel();
        linearRailMasterControllerPanel.resetPanel();
        linearRailSlaveControllerPanel.resetPanel();
        latchXminusControllerPanel.resetPanel();
        latchXplusControllerPanel.resetPanel();
        onlineClampXminusControllerPanel.resetPanel();
        onlineClampXplusControllerPanel.resetPanel();
        onlineClampYminusControllerPanel.resetPanel();
        acGeneralViewPanel.resetPanel();
        acLatchesPanel.resetPanel();
        acTrucksPanel.resetPanel();
        acClampsPanel.resetPanel();
    }

}

==> org-lsst-ccs-subsystem-fcs-gui-5.0.4-sources.jar: org/lsst/ccs/subsystems/fcs/autochanger/ui/AutochangerGatherPanel.java <==
package org.lsst.ccs.subsystems.fcs.autochanger.ui;

import java.util.List;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import org.lsst.ccs.bus.data.KeyValueData;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutoChanger;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutoChangerTrucks;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerLatch;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerOnlineClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerThreeClamps;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerTruck;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerTwoLatches;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByEPOSController;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByHardware;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByPlutoGateway;
import org.lsst.ccs.subsystems.fcs.ui.commons.EPOSControllerPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.GatherPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.PlutoGatewayPanel;

/**
 * This panel gathers all the panels needed for the autochanger GUI.
 * Except the subsystemPanel which is handled by the GeneralPanel.
 * It takes care of the initialization of the panels and the update of the panels.
 *
 * @author virieux
 */
public class AutochangerGatherPanel extends GatherPanel {
    private static final long serialVersionUID = -975949078768889254L;
    
    private static final String AC_PLUTO_GATEWAY_NAME= "acSensorsGateway";
    private static final String AC_TRUCKS_NAME= "autochangerTrucks";

    protected InterfaceAutochangerGUI subs;

    //CANopen devices panels
    protected EPOSControllerPanel linearRailMasterControllerPanel;
    protected EPOSControllerPanel linearRailSlaveControllerPanel;
    protected EPOSControllerPanel latchXminusControllerPanel;
    protected EPOSControllerPanel latchXplusControllerPanel;
    protected EPOSControllerPanel onlineClampXminusControllerPanel;
    protected EPOSControllerPanel onlineClampXplusControllerPanel;
    protected EPOSControllerPanel onlineClampYminusControllerPanel;
    protected PlutoGatewayPanel plutoGatewayPanel;
    
    private EPOSControllerPanel[] controllerPanelsList; 

    //Exchanger hardware panels
    protected AutochangerThreeOnlineClampsPanel onlineClampsPanel;
    
    
    private AutochangerTwoTrucksPanel acTrucksPanel;
    private AutochangerTwoLatchesPanel acLatchesPanel = new AutochangerTwoLatchesPanel();
    private AutochangerThreeOnlineClampsPanel acClampsPanel = new AutochangerThreeOnlineClampsPanel();
    private final AutochangerGeneralViewPanel acGeneralViewPanel = new AutochangerGeneralViewPanel();

    public AutochangerGatherPanel(String tcpProxyName) {
        super(tcpProxyName);
        initPanels();
        setName("AutochangerGatherPanel");
    }

    public AutochangerGatherPanel(InterfaceAutochangerGUI subs, String tcpProxyName) {
        super(tcpProxyName);
        initPanels();
        this.subs = subs;
        this.acClampsPanel.setSubsystem(subs);
        this.acLatchesPanel.setSubsystem(subs);
        this.acTrucksPanel.setSubsystem(subs);
        this.linearRailMasterControllerPanel.setSubsystem(subs);
        this.linearRailSlaveControllerPanel.setSubsystem(subs);
        this.latchXminusControllerPanel.setSubsystem(subs);
        this.latchXplusControllerPanel.setSubsystem(subs);
        this.onlineClampXminusControllerPanel.setSubsystem(subs);
        this.onlineClampXplusControllerPanel.setSubsystem(subs);
        this.onlineClampYminusControllerPanel.setSubsystem(subs);
        setName("AutochangerGatherPanel");
    }



    public AutochangerTwoTrucksPanel getAcTrucksPanel() {
        return acTrucksPanel;
    }

    public AutochangerTwoLatchesPanel getAcLatchesPanel() {
        return acLatchesPanel;
    }

    public AutochangerThreeOnlineClampsPanel getAcClampsPanel() {
        return acClampsPanel;
    }

    public AutochangerGeneralViewPanel getAcGeneralViewPanel() {
        return acGeneralViewPanel;
    }

    public EPOSControllerPanel getLinearRailMasterControllerPanel() {
        return linearRailMasterControllerPanel;
    }

    public EPOSControllerPanel getLinearRailSlaveControllerPanel() {
        return linearRailSlaveControllerPanel;
    }

    public EPOSControllerPanel getLatchXminusControllerPanel() {
        return latchXminusControllerPanel;
    }

    public EPOSControllerPanel getLatchXplusControllerPanel() {
        return latchXplusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampXminusControllerPanel() {
        return onlineClampXminusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampXplusControllerPanel() {
        return onlineClampXplusControllerPanel;
    }

    public EPOSControllerPanel getOnlineClampYminusControllerPanel() {
        return onlineClampYminusControllerPanel;
    }

    public PlutoGatewayPanel getPlutoGatewayPanel() {
        return plutoGatewayPanel;
    }

    @Override
    public void initializeGUIWithConfigInfo(ConfigurationInfo configInfo,
            List<String> hardwareNames) {
        super.initializeGUIWithConfigInfo(configInfo, hardwareNames);
        SwingUtilities.invokeLater(new GuiInitialization(configInfo));
    }
    
    /**
     * Update GUI when a StatusConfigurationInfo message is received on the status bus. 
     * @param configInfo
     */
    @Override
    public void updateFromConfigurationInfo(ConfigurationInfo configInfo) {
        SwingUtilities.invokeLater(new GuiInitialization(configInfo));
    }
    
    @Override
    public void updateFromStatusData(KeyValueData data) {
        
        if (CHANGER_TCPPROXY_NAME.equals(data.getKey())) {
            updateCanOpenHardwarePanel((int)data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByEPOSController) {
            updateCanOpenHardwarePanel((StatusDataPublishedByHardware)data.getValue()); 
            updateController((StatusDataPublishedByEPOSController) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByPlutoGateway) {
            updateCanOpenHardwarePanel((StatusDataPublishedByHardware)data.getValue()); 
            this.plutoGatewayPanel.updateDevice((StatusDataPublishedByHardware)data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutoChanger) {
            updateAutochanger((StatusDataPublishedByAutoChanger) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerTruck) {
            updateTruck(data.getKey(),(StatusDataPublishedByAutochangerTruck) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutoChangerTrucks) {
            updateTrucks((StatusDataPublishedByAutoChangerTrucks) data.getValue());

        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerLatch) {
            updateLatch((StatusDataPublishedByAutochangerLatch) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerTwoLatches) {
            updateLatches((StatusDataPublishedByAutochangerTwoLatches) data.getValue());

        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerOnlineClamp) {
            updateOnlineClamp(data.getKey(), (StatusDataPublishedByAutochangerOnlineClamp) data.getValue());
            
        } else if (data.getValue() instanceof StatusDataPublishedByAutochangerThreeClamps) {
            updateClamps((StatusDataPublishedByAutochangerThreeClamps) data.getValue());
        }
    }

    //TODO simplifier avec une boucle sur les controller panels et un test sur le nom du controleur
    private void updateController(StatusDataPublishedByEPOSController controllerStatus) {
        for (EPOSControllerPanel ctlPanel: controllerPanelsList) {
            ctlPanel.updateController(controllerStatus);
        }
    }
    
    private void updateOnlineClamp(String clampName, StatusDataPublishedByAutochangerOnlineClamp status) {
        switch (clampName) {
            case "onlineClampXminus":
                updateClampXminus(status);
                break;

            case "onlineClampXplus":
                updateClampXplus(status);
                break;

            case "onlineClampYminus":
                updateClampYminus(status);
                break;
                
            default:
                FCSLOG.warning(getName() + " An unexpected onlineClamp name was read on the status bus:" 
                        + clampName);
                break;
        }
    }



    

    /**
     * Initialization of the GUI for data stored in tcpConfiguration. *
     */
    private class GuiInitialization implements Runnable {

        private final ConfigurationInfo configInfo;

        public GuiInitialization(ConfigurationInfo configInfo) {
            this.configInfo = configInfo;
        }

        @Override
        public void run() {
            //** Autochanger General View Panel **/
            acGeneralViewPanel.initializeGui(configInfo);

            /**
             * Autochanger Clamps Panel *
             */
            acClampsPanel.initializeGui(configInfo);

            /**
             * Autochanger Latches Panel *
             */
            acLatchesPanel.initializeGui(configInfo);

            /**
             * Autochanger Trucks Panel *
             */
            
            acTrucksPanel.initializeGui(configInfo);

            /**
             * Linear Rail Master Controller Panel *
             */
            linearRailMasterControllerPanel.initializeGui(configInfo);

            /**
             * Linear Rail Slave Controller Panel*
             */
            linearRailSlaveControllerPanel.initializeGui(configInfo);

            /**
             * Latch Xminus Controller Panel*
             */
            latchXminusControllerPanel.initializeGui(configInfo);

            /**
             * Latch Xplus Controller Panel*
             */
            latchXplusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Xminus Controller Panel*
             */
            onlineClampXminusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Xplus Controller Panel*
             */
            onlineClampXplusControllerPanel.initializeGui(configInfo);

            /**
             * Online Clamp Z Controller Panel*
             */
            onlineClampYminusControllerPanel.initializeGui(configInfo);

            /**
             * PlutoGateway Panel*
             */
            plutoGatewayPanel.initializeGui(configInfo);

        }
    }

    protected void updateClampXminus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampXminus(s);
    }

    protected void updateClampXplus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampXplus(s);
    }

    protected void updateClampYminus(StatusDataPublishedByAutochangerOnlineClamp s) {
        this.acClampsPanel.updateClampYminus(s);
    }

    protected void updateClamps(StatusDataPublishedByAutochangerThreeClamps s) {
        this.acClampsPanel.updateClamps(s);
        this.acGeneralViewPanel.updateClamps(s);
    }

    protected void updateAutochanger(StatusDataPublishedByAutoChanger s) {
        this.acGeneralViewPanel.updateAutochanger(s);
    }

    protected void updateLatch(StatusDataPublishedByAutochangerLatch s) {
        this.acLatchesPanel.updateLatch(s);
    }

    protected void updateLatches(StatusDataPublishedByAutochangerTwoLatches s) {
        this.acLatchesPanel.updateLatches(s);
        this.acGeneralViewPanel.updateLatches(s);
    }
    
    protected void updateTruck(String truckName,StatusDataPublishedByAutochangerTruck s) {
        this.acTrucksPanel.updateTruck(truckName,s);
    }
    
    protected void updateTrucks(StatusDataPublishedByAutoChangerTrucks s) {
        this.acTrucksPanel.updateTrucks(s);
        this.acGeneralViewPanel.updateTrucks(s);
    }

    private void initPanels() {
        //controllers Panels
        linearRailMasterControllerPanel = new EPOSControllerPanel("linearRailMasterController");
        linearRailSlaveControllerPanel = new EPOSControllerPanel("linearRailSlaveController");
        latchXminusControllerPanel = new EPOSControllerPanel("latchXminusController");
        latchXplusControllerPanel = new EPOSControllerPanel("latchXplusController");
        onlineClampXminusControllerPanel = new EPOSControllerPanel("onlineClampXminusController");
        onlineClampXplusControllerPanel = new EPOSControllerPanel("onlineClampXplusController");
        onlineClampYminusControllerPanel = new EPOSControllerPanel("onlineClampYminusController");
        controllerPanelsList = new EPOSControllerPanel[] {linearRailMasterControllerPanel, linearRailSlaveControllerPanel, 
            latchXminusControllerPanel,latchXplusControllerPanel, 
            onlineClampXminusControllerPanel, onlineClampXplusControllerPanel, onlineClampYminusControllerPanel};
        //plutoGatewayPanel
        plutoGatewayPanel = new PlutoGatewayPanel(AC_PLUTO_GATEWAY_NAME);

        acClampsPanel = new AutochangerThreeOnlineClampsPanel();
        acLatchesPanel = new AutochangerTwoLatchesPanel();
        acTrucksPanel = new AutochangerTwoTrucksPanel(AC_TRUCKS_NAME);
    }
    
    @Override
    public void resetPanel() {
        super.resetPanel();
        linearRailMasterControllerPanel.resetPanel();
        linearRailSlaveControllerPanel.resetPanel();
        latchXminusControllerPanel.resetPanel();
        latchXplusControllerPanel.resetPanel();
        onlineClampXminusControllerPanel.resetPanel();
        onlineClampXplusControllerPanel.resetPanel();
        onlineClampYminusControllerPanel.resetPanel();
        acGeneralViewPanel.resetPanel();
        acLatchesPanel.resetPanel();
        acTrucksPanel.resetPanel();
        acClampsPanel.resetPanel();
    }

}
